use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007002
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
CA
CGI
UA
proxying
Christian
Hansen
chansen
David
Golden
dagolden
Alan
Gardner
gardner
Alessandro
Ghedini
al3xbio
Sinan
Unur
nanis
Brad
Gilbert
bgills
brian
carlson
sandals
Chris
Nehren
apeiron
Weyl
cweyl
Claes
Jakobsson
claes
Clinton
Gormley
clint
xdg
Dean
Pearce
pearce
Edward
Zborowski
ed
James
Raspass
jraspass
Jeremy
Mates
jmates
Jess
Robinson
castaway
Karen
Etheridge
ether
Lukas
Eklund
leklund
Martin
Evans
mjegh
Bright
mlbright
Mike
Doherty
doherty
Olaf
Alders
olaf
Olivier
Mengué
dolmen
Petr
Písař
ppisar
SkyMarshal
skymarshal1729
Sören
Kornetzki
soeren
Steve
Grazzini
steve
Syohei
YOSHIDA
syohex
Tatsuhiko
Miyagawa
miyagawa
Tom
Hukins
tom
Tony
Cook
tony
lib
HTTP
Tiny
